#include <libint2.h>

#ifdef __cplusplus
extern "C" {
#endif
void OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3) {

LIBINT2_REALTYPE*const  stack = target;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
LIBINT2_REALTYPE fp164;
fp164 = inteval->WQ_z[vi] * src1[((hsi*36+15)*1+lsi)*1];
LIBINT2_REALTYPE fp165;
fp165 = inteval->QC_z[vi] * src0[((hsi*36+15)*1+lsi)*1];
LIBINT2_REALTYPE fp163;
fp163 = fp165 + fp164;
target[((hsi*45+22)*1+lsi)*1] = fp163;
LIBINT2_REALTYPE fp169;
fp169 = inteval->roe[vi] * src3[((hsi*28+10)*1+lsi)*1];
LIBINT2_REALTYPE fp168;
fp168 = src2[((hsi*28+10)*1+lsi)*1] - fp169;
LIBINT2_REALTYPE fp170;
fp170 = 5 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp167;
fp167 = fp170 * fp168;
LIBINT2_REALTYPE fp172;
fp172 = inteval->WQ_y[vi] * src1[((hsi*36+15)*1+lsi)*1];
LIBINT2_REALTYPE fp173;
fp173 = inteval->QC_y[vi] * src0[((hsi*36+15)*1+lsi)*1];
LIBINT2_REALTYPE fp171;
fp171 = fp173 + fp172;
LIBINT2_REALTYPE fp166;
fp166 = fp171 + fp167;
target[((hsi*45+21)*1+lsi)*1] = fp166;
LIBINT2_REALTYPE fp177;
fp177 = inteval->roe[vi] * src3[((hsi*28+9)*1+lsi)*1];
LIBINT2_REALTYPE fp176;
fp176 = src2[((hsi*28+9)*1+lsi)*1] - fp177;
LIBINT2_REALTYPE fp178;
fp178 = 4 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp175;
fp175 = fp178 * fp176;
LIBINT2_REALTYPE fp180;
fp180 = inteval->WQ_z[vi] * src1[((hsi*36+14)*1+lsi)*1];
LIBINT2_REALTYPE fp181;
fp181 = inteval->QC_z[vi] * src0[((hsi*36+14)*1+lsi)*1];
LIBINT2_REALTYPE fp179;
fp179 = fp181 + fp180;
LIBINT2_REALTYPE fp174;
fp174 = fp179 + fp175;
target[((hsi*45+20)*1+lsi)*1] = fp174;
LIBINT2_REALTYPE fp185;
fp185 = inteval->roe[vi] * src3[((hsi*28+8)*1+lsi)*1];
LIBINT2_REALTYPE fp184;
fp184 = src2[((hsi*28+8)*1+lsi)*1] - fp185;
LIBINT2_REALTYPE fp186;
fp186 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp183;
fp183 = fp186 * fp184;
LIBINT2_REALTYPE fp188;
fp188 = inteval->WQ_z[vi] * src1[((hsi*36+13)*1+lsi)*1];
LIBINT2_REALTYPE fp189;
fp189 = inteval->QC_z[vi] * src0[((hsi*36+13)*1+lsi)*1];
LIBINT2_REALTYPE fp187;
fp187 = fp189 + fp188;
LIBINT2_REALTYPE fp182;
fp182 = fp187 + fp183;
target[((hsi*45+19)*1+lsi)*1] = fp182;
LIBINT2_REALTYPE fp193;
fp193 = inteval->roe[vi] * src3[((hsi*28+7)*1+lsi)*1];
LIBINT2_REALTYPE fp192;
fp192 = src2[((hsi*28+7)*1+lsi)*1] - fp193;
LIBINT2_REALTYPE fp194;
fp194 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp191;
fp191 = fp194 * fp192;
LIBINT2_REALTYPE fp196;
fp196 = inteval->WQ_z[vi] * src1[((hsi*36+12)*1+lsi)*1];
LIBINT2_REALTYPE fp197;
fp197 = inteval->QC_z[vi] * src0[((hsi*36+12)*1+lsi)*1];
LIBINT2_REALTYPE fp195;
fp195 = fp197 + fp196;
LIBINT2_REALTYPE fp190;
fp190 = fp195 + fp191;
target[((hsi*45+18)*1+lsi)*1] = fp190;
LIBINT2_REALTYPE fp201;
fp201 = inteval->roe[vi] * src3[((hsi*28+6)*1+lsi)*1];
LIBINT2_REALTYPE fp200;
fp200 = src2[((hsi*28+6)*1+lsi)*1] - fp201;
LIBINT2_REALTYPE fp199;
fp199 = inteval->oo2e[vi] * fp200;
LIBINT2_REALTYPE fp203;
fp203 = inteval->WQ_z[vi] * src1[((hsi*36+11)*1+lsi)*1];
LIBINT2_REALTYPE fp204;
fp204 = inteval->QC_z[vi] * src0[((hsi*36+11)*1+lsi)*1];
LIBINT2_REALTYPE fp202;
fp202 = fp204 + fp203;
LIBINT2_REALTYPE fp198;
fp198 = fp202 + fp199;
target[((hsi*45+17)*1+lsi)*1] = fp198;
LIBINT2_REALTYPE fp206;
fp206 = inteval->WQ_z[vi] * src1[((hsi*36+10)*1+lsi)*1];
LIBINT2_REALTYPE fp207;
fp207 = inteval->QC_z[vi] * src0[((hsi*36+10)*1+lsi)*1];
LIBINT2_REALTYPE fp205;
fp205 = fp207 + fp206;
target[((hsi*45+16)*1+lsi)*1] = fp205;
LIBINT2_REALTYPE fp211;
fp211 = inteval->roe[vi] * src3[((hsi*28+6)*1+lsi)*1];
LIBINT2_REALTYPE fp210;
fp210 = src2[((hsi*28+6)*1+lsi)*1] - fp211;
LIBINT2_REALTYPE fp212;
fp212 = 4 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp209;
fp209 = fp212 * fp210;
LIBINT2_REALTYPE fp214;
fp214 = inteval->WQ_y[vi] * src1[((hsi*36+10)*1+lsi)*1];
LIBINT2_REALTYPE fp215;
fp215 = inteval->QC_y[vi] * src0[((hsi*36+10)*1+lsi)*1];
LIBINT2_REALTYPE fp213;
fp213 = fp215 + fp214;
LIBINT2_REALTYPE fp208;
fp208 = fp213 + fp209;
target[((hsi*45+15)*1+lsi)*1] = fp208;
LIBINT2_REALTYPE fp219;
fp219 = inteval->roe[vi] * src3[((hsi*28+5)*1+lsi)*1];
LIBINT2_REALTYPE fp218;
fp218 = src2[((hsi*28+5)*1+lsi)*1] - fp219;
LIBINT2_REALTYPE fp220;
fp220 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp217;
fp217 = fp220 * fp218;
LIBINT2_REALTYPE fp222;
fp222 = inteval->WQ_z[vi] * src1[((hsi*36+9)*1+lsi)*1];
LIBINT2_REALTYPE fp223;
fp223 = inteval->QC_z[vi] * src0[((hsi*36+9)*1+lsi)*1];
LIBINT2_REALTYPE fp221;
fp221 = fp223 + fp222;
LIBINT2_REALTYPE fp216;
fp216 = fp221 + fp217;
target[((hsi*45+14)*1+lsi)*1] = fp216;
LIBINT2_REALTYPE fp227;
fp227 = inteval->roe[vi] * src3[((hsi*28+4)*1+lsi)*1];
LIBINT2_REALTYPE fp226;
fp226 = src2[((hsi*28+4)*1+lsi)*1] - fp227;
LIBINT2_REALTYPE fp228;
fp228 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp225;
fp225 = fp228 * fp226;
LIBINT2_REALTYPE fp230;
fp230 = inteval->WQ_z[vi] * src1[((hsi*36+8)*1+lsi)*1];
LIBINT2_REALTYPE fp231;
fp231 = inteval->QC_z[vi] * src0[((hsi*36+8)*1+lsi)*1];
LIBINT2_REALTYPE fp229;
fp229 = fp231 + fp230;
LIBINT2_REALTYPE fp224;
fp224 = fp229 + fp225;
target[((hsi*45+13)*1+lsi)*1] = fp224;
LIBINT2_REALTYPE fp235;
fp235 = inteval->roe[vi] * src3[((hsi*28+3)*1+lsi)*1];
LIBINT2_REALTYPE fp234;
fp234 = src2[((hsi*28+3)*1+lsi)*1] - fp235;
LIBINT2_REALTYPE fp233;
fp233 = inteval->oo2e[vi] * fp234;
LIBINT2_REALTYPE fp237;
fp237 = inteval->WQ_z[vi] * src1[((hsi*36+7)*1+lsi)*1];
LIBINT2_REALTYPE fp238;
fp238 = inteval->QC_z[vi] * src0[((hsi*36+7)*1+lsi)*1];
LIBINT2_REALTYPE fp236;
fp236 = fp238 + fp237;
LIBINT2_REALTYPE fp232;
fp232 = fp236 + fp233;
target[((hsi*45+12)*1+lsi)*1] = fp232;
LIBINT2_REALTYPE fp240;
fp240 = inteval->WQ_z[vi] * src1[((hsi*36+6)*1+lsi)*1];
LIBINT2_REALTYPE fp241;
fp241 = inteval->QC_z[vi] * src0[((hsi*36+6)*1+lsi)*1];
LIBINT2_REALTYPE fp239;
fp239 = fp241 + fp240;
target[((hsi*45+11)*1+lsi)*1] = fp239;
LIBINT2_REALTYPE fp245;
fp245 = inteval->roe[vi] * src3[((hsi*28+3)*1+lsi)*1];
LIBINT2_REALTYPE fp244;
fp244 = src2[((hsi*28+3)*1+lsi)*1] - fp245;
LIBINT2_REALTYPE fp246;
fp246 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp243;
fp243 = fp246 * fp244;
LIBINT2_REALTYPE fp248;
fp248 = inteval->WQ_y[vi] * src1[((hsi*36+6)*1+lsi)*1];
LIBINT2_REALTYPE fp249;
fp249 = inteval->QC_y[vi] * src0[((hsi*36+6)*1+lsi)*1];
LIBINT2_REALTYPE fp247;
fp247 = fp249 + fp248;
LIBINT2_REALTYPE fp242;
fp242 = fp247 + fp243;
target[((hsi*45+10)*1+lsi)*1] = fp242;
LIBINT2_REALTYPE fp253;
fp253 = inteval->roe[vi] * src3[((hsi*28+2)*1+lsi)*1];
LIBINT2_REALTYPE fp252;
fp252 = src2[((hsi*28+2)*1+lsi)*1] - fp253;
LIBINT2_REALTYPE fp254;
fp254 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp251;
fp251 = fp254 * fp252;
LIBINT2_REALTYPE fp256;
fp256 = inteval->WQ_z[vi] * src1[((hsi*36+5)*1+lsi)*1];
LIBINT2_REALTYPE fp257;
fp257 = inteval->QC_z[vi] * src0[((hsi*36+5)*1+lsi)*1];
LIBINT2_REALTYPE fp255;
fp255 = fp257 + fp256;
LIBINT2_REALTYPE fp250;
fp250 = fp255 + fp251;
target[((hsi*45+9)*1+lsi)*1] = fp250;
LIBINT2_REALTYPE fp261;
fp261 = inteval->roe[vi] * src3[((hsi*28+1)*1+lsi)*1];
LIBINT2_REALTYPE fp260;
fp260 = src2[((hsi*28+1)*1+lsi)*1] - fp261;
LIBINT2_REALTYPE fp259;
fp259 = inteval->oo2e[vi] * fp260;
LIBINT2_REALTYPE fp263;
fp263 = inteval->WQ_z[vi] * src1[((hsi*36+4)*1+lsi)*1];
LIBINT2_REALTYPE fp264;
fp264 = inteval->QC_z[vi] * src0[((hsi*36+4)*1+lsi)*1];
LIBINT2_REALTYPE fp262;
fp262 = fp264 + fp263;
LIBINT2_REALTYPE fp258;
fp258 = fp262 + fp259;
target[((hsi*45+8)*1+lsi)*1] = fp258;
LIBINT2_REALTYPE fp266;
fp266 = inteval->WQ_z[vi] * src1[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp267;
fp267 = inteval->QC_z[vi] * src0[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp265;
fp265 = fp267 + fp266;
target[((hsi*45+7)*1+lsi)*1] = fp265;
LIBINT2_REALTYPE fp271;
fp271 = inteval->roe[vi] * src3[((hsi*28+1)*1+lsi)*1];
LIBINT2_REALTYPE fp270;
fp270 = src2[((hsi*28+1)*1+lsi)*1] - fp271;
LIBINT2_REALTYPE fp272;
fp272 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp269;
fp269 = fp272 * fp270;
LIBINT2_REALTYPE fp274;
fp274 = inteval->WQ_y[vi] * src1[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp275;
fp275 = inteval->QC_y[vi] * src0[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp273;
fp273 = fp275 + fp274;
LIBINT2_REALTYPE fp268;
fp268 = fp273 + fp269;
target[((hsi*45+6)*1+lsi)*1] = fp268;
LIBINT2_REALTYPE fp279;
fp279 = inteval->roe[vi] * src3[((hsi*28+0)*1+lsi)*1];
LIBINT2_REALTYPE fp278;
fp278 = src2[((hsi*28+0)*1+lsi)*1] - fp279;
LIBINT2_REALTYPE fp277;
fp277 = inteval->oo2e[vi] * fp278;
LIBINT2_REALTYPE fp281;
fp281 = inteval->WQ_z[vi] * src1[((hsi*36+2)*1+lsi)*1];
LIBINT2_REALTYPE fp282;
fp282 = inteval->QC_z[vi] * src0[((hsi*36+2)*1+lsi)*1];
LIBINT2_REALTYPE fp280;
fp280 = fp282 + fp281;
LIBINT2_REALTYPE fp276;
fp276 = fp280 + fp277;
target[((hsi*45+5)*1+lsi)*1] = fp276;
LIBINT2_REALTYPE fp284;
fp284 = inteval->WQ_z[vi] * src1[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp285;
fp285 = inteval->QC_z[vi] * src0[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp283;
fp283 = fp285 + fp284;
target[((hsi*45+4)*1+lsi)*1] = fp283;
LIBINT2_REALTYPE fp289;
fp289 = inteval->roe[vi] * src3[((hsi*28+0)*1+lsi)*1];
LIBINT2_REALTYPE fp288;
fp288 = src2[((hsi*28+0)*1+lsi)*1] - fp289;
LIBINT2_REALTYPE fp287;
fp287 = inteval->oo2e[vi] * fp288;
LIBINT2_REALTYPE fp291;
fp291 = inteval->WQ_y[vi] * src1[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp292;
fp292 = inteval->QC_y[vi] * src0[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp290;
fp290 = fp292 + fp291;
LIBINT2_REALTYPE fp286;
fp286 = fp290 + fp287;
target[((hsi*45+3)*1+lsi)*1] = fp286;
LIBINT2_REALTYPE fp294;
fp294 = inteval->WQ_z[vi] * src1[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp295;
fp295 = inteval->QC_z[vi] * src0[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp293;
fp293 = fp295 + fp294;
target[((hsi*45+2)*1+lsi)*1] = fp293;
LIBINT2_REALTYPE fp297;
fp297 = inteval->WQ_y[vi] * src1[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp298;
fp298 = inteval->QC_y[vi] * src0[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp296;
fp296 = fp298 + fp297;
target[((hsi*45+1)*1+lsi)*1] = fp296;
LIBINT2_REALTYPE fp302;
fp302 = inteval->roe[vi] * src3[((hsi*28+0)*1+lsi)*1];
LIBINT2_REALTYPE fp301;
fp301 = src2[((hsi*28+0)*1+lsi)*1] - fp302;
LIBINT2_REALTYPE fp303;
fp303 = 7 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp300;
fp300 = fp303 * fp301;
LIBINT2_REALTYPE fp305;
fp305 = inteval->WQ_x[vi] * src1[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp306;
fp306 = inteval->QC_x[vi] * src0[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp304;
fp304 = fp306 + fp305;
LIBINT2_REALTYPE fp299;
fp299 = fp304 + fp300;
target[((hsi*45+0)*1+lsi)*1] = fp299;
LIBINT2_REALTYPE fp3;
fp3 = inteval->roe[vi] * src3[((hsi*28+27)*1+lsi)*1];
LIBINT2_REALTYPE fp2;
fp2 = src2[((hsi*28+27)*1+lsi)*1] - fp3;
LIBINT2_REALTYPE fp4;
fp4 = 7 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp1;
fp1 = fp4 * fp2;
LIBINT2_REALTYPE fp6;
fp6 = inteval->WQ_z[vi] * src1[((hsi*36+35)*1+lsi)*1];
LIBINT2_REALTYPE fp7;
fp7 = inteval->QC_z[vi] * src0[((hsi*36+35)*1+lsi)*1];
LIBINT2_REALTYPE fp5;
fp5 = fp7 + fp6;
LIBINT2_REALTYPE fp0;
fp0 = fp5 + fp1;
target[((hsi*45+44)*1+lsi)*1] = fp0;
LIBINT2_REALTYPE fp11;
fp11 = inteval->roe[vi] * src3[((hsi*28+26)*1+lsi)*1];
LIBINT2_REALTYPE fp10;
fp10 = src2[((hsi*28+26)*1+lsi)*1] - fp11;
LIBINT2_REALTYPE fp12;
fp12 = 6 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp9;
fp9 = fp12 * fp10;
LIBINT2_REALTYPE fp14;
fp14 = inteval->WQ_z[vi] * src1[((hsi*36+34)*1+lsi)*1];
LIBINT2_REALTYPE fp15;
fp15 = inteval->QC_z[vi] * src0[((hsi*36+34)*1+lsi)*1];
LIBINT2_REALTYPE fp13;
fp13 = fp15 + fp14;
LIBINT2_REALTYPE fp8;
fp8 = fp13 + fp9;
target[((hsi*45+43)*1+lsi)*1] = fp8;
LIBINT2_REALTYPE fp19;
fp19 = inteval->roe[vi] * src3[((hsi*28+25)*1+lsi)*1];
LIBINT2_REALTYPE fp18;
fp18 = src2[((hsi*28+25)*1+lsi)*1] - fp19;
LIBINT2_REALTYPE fp20;
fp20 = 5 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp17;
fp17 = fp20 * fp18;
LIBINT2_REALTYPE fp22;
fp22 = inteval->WQ_z[vi] * src1[((hsi*36+33)*1+lsi)*1];
LIBINT2_REALTYPE fp23;
fp23 = inteval->QC_z[vi] * src0[((hsi*36+33)*1+lsi)*1];
LIBINT2_REALTYPE fp21;
fp21 = fp23 + fp22;
LIBINT2_REALTYPE fp16;
fp16 = fp21 + fp17;
target[((hsi*45+42)*1+lsi)*1] = fp16;
LIBINT2_REALTYPE fp27;
fp27 = inteval->roe[vi] * src3[((hsi*28+24)*1+lsi)*1];
LIBINT2_REALTYPE fp26;
fp26 = src2[((hsi*28+24)*1+lsi)*1] - fp27;
LIBINT2_REALTYPE fp28;
fp28 = 4 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp25;
fp25 = fp28 * fp26;
LIBINT2_REALTYPE fp30;
fp30 = inteval->WQ_z[vi] * src1[((hsi*36+32)*1+lsi)*1];
LIBINT2_REALTYPE fp31;
fp31 = inteval->QC_z[vi] * src0[((hsi*36+32)*1+lsi)*1];
LIBINT2_REALTYPE fp29;
fp29 = fp31 + fp30;
LIBINT2_REALTYPE fp24;
fp24 = fp29 + fp25;
target[((hsi*45+41)*1+lsi)*1] = fp24;
LIBINT2_REALTYPE fp35;
fp35 = inteval->roe[vi] * src3[((hsi*28+23)*1+lsi)*1];
LIBINT2_REALTYPE fp34;
fp34 = src2[((hsi*28+23)*1+lsi)*1] - fp35;
LIBINT2_REALTYPE fp36;
fp36 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp33;
fp33 = fp36 * fp34;
LIBINT2_REALTYPE fp38;
fp38 = inteval->WQ_z[vi] * src1[((hsi*36+31)*1+lsi)*1];
LIBINT2_REALTYPE fp39;
fp39 = inteval->QC_z[vi] * src0[((hsi*36+31)*1+lsi)*1];
LIBINT2_REALTYPE fp37;
fp37 = fp39 + fp38;
LIBINT2_REALTYPE fp32;
fp32 = fp37 + fp33;
target[((hsi*45+40)*1+lsi)*1] = fp32;
LIBINT2_REALTYPE fp43;
fp43 = inteval->roe[vi] * src3[((hsi*28+22)*1+lsi)*1];
LIBINT2_REALTYPE fp42;
fp42 = src2[((hsi*28+22)*1+lsi)*1] - fp43;
LIBINT2_REALTYPE fp44;
fp44 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp41;
fp41 = fp44 * fp42;
LIBINT2_REALTYPE fp46;
fp46 = inteval->WQ_z[vi] * src1[((hsi*36+30)*1+lsi)*1];
LIBINT2_REALTYPE fp47;
fp47 = inteval->QC_z[vi] * src0[((hsi*36+30)*1+lsi)*1];
LIBINT2_REALTYPE fp45;
fp45 = fp47 + fp46;
LIBINT2_REALTYPE fp40;
fp40 = fp45 + fp41;
target[((hsi*45+39)*1+lsi)*1] = fp40;
LIBINT2_REALTYPE fp51;
fp51 = inteval->roe[vi] * src3[((hsi*28+21)*1+lsi)*1];
LIBINT2_REALTYPE fp50;
fp50 = src2[((hsi*28+21)*1+lsi)*1] - fp51;
LIBINT2_REALTYPE fp49;
fp49 = inteval->oo2e[vi] * fp50;
LIBINT2_REALTYPE fp53;
fp53 = inteval->WQ_z[vi] * src1[((hsi*36+29)*1+lsi)*1];
LIBINT2_REALTYPE fp54;
fp54 = inteval->QC_z[vi] * src0[((hsi*36+29)*1+lsi)*1];
LIBINT2_REALTYPE fp52;
fp52 = fp54 + fp53;
LIBINT2_REALTYPE fp48;
fp48 = fp52 + fp49;
target[((hsi*45+38)*1+lsi)*1] = fp48;
LIBINT2_REALTYPE fp56;
fp56 = inteval->WQ_z[vi] * src1[((hsi*36+28)*1+lsi)*1];
LIBINT2_REALTYPE fp57;
fp57 = inteval->QC_z[vi] * src0[((hsi*36+28)*1+lsi)*1];
LIBINT2_REALTYPE fp55;
fp55 = fp57 + fp56;
target[((hsi*45+37)*1+lsi)*1] = fp55;
LIBINT2_REALTYPE fp61;
fp61 = inteval->roe[vi] * src3[((hsi*28+21)*1+lsi)*1];
LIBINT2_REALTYPE fp60;
fp60 = src2[((hsi*28+21)*1+lsi)*1] - fp61;
LIBINT2_REALTYPE fp62;
fp62 = 7 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp59;
fp59 = fp62 * fp60;
LIBINT2_REALTYPE fp64;
fp64 = inteval->WQ_y[vi] * src1[((hsi*36+28)*1+lsi)*1];
LIBINT2_REALTYPE fp65;
fp65 = inteval->QC_y[vi] * src0[((hsi*36+28)*1+lsi)*1];
LIBINT2_REALTYPE fp63;
fp63 = fp65 + fp64;
LIBINT2_REALTYPE fp58;
fp58 = fp63 + fp59;
target[((hsi*45+36)*1+lsi)*1] = fp58;
LIBINT2_REALTYPE fp69;
fp69 = inteval->roe[vi] * src3[((hsi*28+20)*1+lsi)*1];
LIBINT2_REALTYPE fp68;
fp68 = src2[((hsi*28+20)*1+lsi)*1] - fp69;
LIBINT2_REALTYPE fp70;
fp70 = 6 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp67;
fp67 = fp70 * fp68;
LIBINT2_REALTYPE fp72;
fp72 = inteval->WQ_z[vi] * src1[((hsi*36+27)*1+lsi)*1];
LIBINT2_REALTYPE fp73;
fp73 = inteval->QC_z[vi] * src0[((hsi*36+27)*1+lsi)*1];
LIBINT2_REALTYPE fp71;
fp71 = fp73 + fp72;
LIBINT2_REALTYPE fp66;
fp66 = fp71 + fp67;
target[((hsi*45+35)*1+lsi)*1] = fp66;
LIBINT2_REALTYPE fp77;
fp77 = inteval->roe[vi] * src3[((hsi*28+19)*1+lsi)*1];
LIBINT2_REALTYPE fp76;
fp76 = src2[((hsi*28+19)*1+lsi)*1] - fp77;
LIBINT2_REALTYPE fp78;
fp78 = 5 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp75;
fp75 = fp78 * fp76;
LIBINT2_REALTYPE fp80;
fp80 = inteval->WQ_z[vi] * src1[((hsi*36+26)*1+lsi)*1];
LIBINT2_REALTYPE fp81;
fp81 = inteval->QC_z[vi] * src0[((hsi*36+26)*1+lsi)*1];
LIBINT2_REALTYPE fp79;
fp79 = fp81 + fp80;
LIBINT2_REALTYPE fp74;
fp74 = fp79 + fp75;
target[((hsi*45+34)*1+lsi)*1] = fp74;
LIBINT2_REALTYPE fp85;
fp85 = inteval->roe[vi] * src3[((hsi*28+18)*1+lsi)*1];
LIBINT2_REALTYPE fp84;
fp84 = src2[((hsi*28+18)*1+lsi)*1] - fp85;
LIBINT2_REALTYPE fp86;
fp86 = 4 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp83;
fp83 = fp86 * fp84;
LIBINT2_REALTYPE fp88;
fp88 = inteval->WQ_z[vi] * src1[((hsi*36+25)*1+lsi)*1];
LIBINT2_REALTYPE fp89;
fp89 = inteval->QC_z[vi] * src0[((hsi*36+25)*1+lsi)*1];
LIBINT2_REALTYPE fp87;
fp87 = fp89 + fp88;
LIBINT2_REALTYPE fp82;
fp82 = fp87 + fp83;
target[((hsi*45+33)*1+lsi)*1] = fp82;
LIBINT2_REALTYPE fp93;
fp93 = inteval->roe[vi] * src3[((hsi*28+17)*1+lsi)*1];
LIBINT2_REALTYPE fp92;
fp92 = src2[((hsi*28+17)*1+lsi)*1] - fp93;
LIBINT2_REALTYPE fp94;
fp94 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp91;
fp91 = fp94 * fp92;
LIBINT2_REALTYPE fp96;
fp96 = inteval->WQ_z[vi] * src1[((hsi*36+24)*1+lsi)*1];
LIBINT2_REALTYPE fp97;
fp97 = inteval->QC_z[vi] * src0[((hsi*36+24)*1+lsi)*1];
LIBINT2_REALTYPE fp95;
fp95 = fp97 + fp96;
LIBINT2_REALTYPE fp90;
fp90 = fp95 + fp91;
target[((hsi*45+32)*1+lsi)*1] = fp90;
LIBINT2_REALTYPE fp101;
fp101 = inteval->roe[vi] * src3[((hsi*28+16)*1+lsi)*1];
LIBINT2_REALTYPE fp100;
fp100 = src2[((hsi*28+16)*1+lsi)*1] - fp101;
LIBINT2_REALTYPE fp102;
fp102 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp99;
fp99 = fp102 * fp100;
LIBINT2_REALTYPE fp104;
fp104 = inteval->WQ_z[vi] * src1[((hsi*36+23)*1+lsi)*1];
LIBINT2_REALTYPE fp105;
fp105 = inteval->QC_z[vi] * src0[((hsi*36+23)*1+lsi)*1];
LIBINT2_REALTYPE fp103;
fp103 = fp105 + fp104;
LIBINT2_REALTYPE fp98;
fp98 = fp103 + fp99;
target[((hsi*45+31)*1+lsi)*1] = fp98;
LIBINT2_REALTYPE fp109;
fp109 = inteval->roe[vi] * src3[((hsi*28+15)*1+lsi)*1];
LIBINT2_REALTYPE fp108;
fp108 = src2[((hsi*28+15)*1+lsi)*1] - fp109;
LIBINT2_REALTYPE fp107;
fp107 = inteval->oo2e[vi] * fp108;
LIBINT2_REALTYPE fp111;
fp111 = inteval->WQ_z[vi] * src1[((hsi*36+22)*1+lsi)*1];
LIBINT2_REALTYPE fp112;
fp112 = inteval->QC_z[vi] * src0[((hsi*36+22)*1+lsi)*1];
LIBINT2_REALTYPE fp110;
fp110 = fp112 + fp111;
LIBINT2_REALTYPE fp106;
fp106 = fp110 + fp107;
target[((hsi*45+30)*1+lsi)*1] = fp106;
LIBINT2_REALTYPE fp114;
fp114 = inteval->WQ_z[vi] * src1[((hsi*36+21)*1+lsi)*1];
LIBINT2_REALTYPE fp115;
fp115 = inteval->QC_z[vi] * src0[((hsi*36+21)*1+lsi)*1];
LIBINT2_REALTYPE fp113;
fp113 = fp115 + fp114;
target[((hsi*45+29)*1+lsi)*1] = fp113;
LIBINT2_REALTYPE fp119;
fp119 = inteval->roe[vi] * src3[((hsi*28+15)*1+lsi)*1];
LIBINT2_REALTYPE fp118;
fp118 = src2[((hsi*28+15)*1+lsi)*1] - fp119;
LIBINT2_REALTYPE fp120;
fp120 = 6 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp117;
fp117 = fp120 * fp118;
LIBINT2_REALTYPE fp122;
fp122 = inteval->WQ_y[vi] * src1[((hsi*36+21)*1+lsi)*1];
LIBINT2_REALTYPE fp123;
fp123 = inteval->QC_y[vi] * src0[((hsi*36+21)*1+lsi)*1];
LIBINT2_REALTYPE fp121;
fp121 = fp123 + fp122;
LIBINT2_REALTYPE fp116;
fp116 = fp121 + fp117;
target[((hsi*45+28)*1+lsi)*1] = fp116;
LIBINT2_REALTYPE fp127;
fp127 = inteval->roe[vi] * src3[((hsi*28+14)*1+lsi)*1];
LIBINT2_REALTYPE fp126;
fp126 = src2[((hsi*28+14)*1+lsi)*1] - fp127;
LIBINT2_REALTYPE fp128;
fp128 = 5 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp125;
fp125 = fp128 * fp126;
LIBINT2_REALTYPE fp130;
fp130 = inteval->WQ_z[vi] * src1[((hsi*36+20)*1+lsi)*1];
LIBINT2_REALTYPE fp131;
fp131 = inteval->QC_z[vi] * src0[((hsi*36+20)*1+lsi)*1];
LIBINT2_REALTYPE fp129;
fp129 = fp131 + fp130;
LIBINT2_REALTYPE fp124;
fp124 = fp129 + fp125;
target[((hsi*45+27)*1+lsi)*1] = fp124;
LIBINT2_REALTYPE fp135;
fp135 = inteval->roe[vi] * src3[((hsi*28+13)*1+lsi)*1];
LIBINT2_REALTYPE fp134;
fp134 = src2[((hsi*28+13)*1+lsi)*1] - fp135;
LIBINT2_REALTYPE fp136;
fp136 = 4 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp133;
fp133 = fp136 * fp134;
LIBINT2_REALTYPE fp138;
fp138 = inteval->WQ_z[vi] * src1[((hsi*36+19)*1+lsi)*1];
LIBINT2_REALTYPE fp139;
fp139 = inteval->QC_z[vi] * src0[((hsi*36+19)*1+lsi)*1];
LIBINT2_REALTYPE fp137;
fp137 = fp139 + fp138;
LIBINT2_REALTYPE fp132;
fp132 = fp137 + fp133;
target[((hsi*45+26)*1+lsi)*1] = fp132;
LIBINT2_REALTYPE fp143;
fp143 = inteval->roe[vi] * src3[((hsi*28+12)*1+lsi)*1];
LIBINT2_REALTYPE fp142;
fp142 = src2[((hsi*28+12)*1+lsi)*1] - fp143;
LIBINT2_REALTYPE fp144;
fp144 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp141;
fp141 = fp144 * fp142;
LIBINT2_REALTYPE fp146;
fp146 = inteval->WQ_z[vi] * src1[((hsi*36+18)*1+lsi)*1];
LIBINT2_REALTYPE fp147;
fp147 = inteval->QC_z[vi] * src0[((hsi*36+18)*1+lsi)*1];
LIBINT2_REALTYPE fp145;
fp145 = fp147 + fp146;
LIBINT2_REALTYPE fp140;
fp140 = fp145 + fp141;
target[((hsi*45+25)*1+lsi)*1] = fp140;
LIBINT2_REALTYPE fp151;
fp151 = inteval->roe[vi] * src3[((hsi*28+11)*1+lsi)*1];
LIBINT2_REALTYPE fp150;
fp150 = src2[((hsi*28+11)*1+lsi)*1] - fp151;
LIBINT2_REALTYPE fp152;
fp152 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp149;
fp149 = fp152 * fp150;
LIBINT2_REALTYPE fp154;
fp154 = inteval->WQ_z[vi] * src1[((hsi*36+17)*1+lsi)*1];
LIBINT2_REALTYPE fp155;
fp155 = inteval->QC_z[vi] * src0[((hsi*36+17)*1+lsi)*1];
LIBINT2_REALTYPE fp153;
fp153 = fp155 + fp154;
LIBINT2_REALTYPE fp148;
fp148 = fp153 + fp149;
target[((hsi*45+24)*1+lsi)*1] = fp148;
LIBINT2_REALTYPE fp159;
fp159 = inteval->roe[vi] * src3[((hsi*28+10)*1+lsi)*1];
LIBINT2_REALTYPE fp158;
fp158 = src2[((hsi*28+10)*1+lsi)*1] - fp159;
LIBINT2_REALTYPE fp157;
fp157 = inteval->oo2e[vi] * fp158;
LIBINT2_REALTYPE fp161;
fp161 = inteval->WQ_z[vi] * src1[((hsi*36+16)*1+lsi)*1];
LIBINT2_REALTYPE fp162;
fp162 = inteval->QC_z[vi] * src0[((hsi*36+16)*1+lsi)*1];
LIBINT2_REALTYPE fp160;
fp160 = fp162 + fp161;
LIBINT2_REALTYPE fp156;
fp156 = fp160 + fp157;
target[((hsi*45+23)*1+lsi)*1] = fp156;
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 307 */
}

#ifdef __cplusplus
};
#endif
